Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1054)

Unified Diff: content/browser/download/download_item_impl.h

Issue 14955002: [Resumption 6/11] Add a RESUMING_INTERNAL state to DownloadItem. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/download/download_item_impl.h
diff --git a/content/browser/download/download_item_impl.h b/content/browser/download/download_item_impl.h
index 083a1591ab46961772d844a62fc0e199b27c90fe..349e8713986d1f1042f550db572836dc563a3510 100644
--- a/content/browser/download/download_item_impl.h
+++ b/content/browser/download/download_item_impl.h
@@ -234,9 +234,13 @@ class CONTENT_EXPORT DownloadItemImpl
CANCELLED_INTERNAL,
// An error has interrupted the download.
// Only incoming transition IN_PROGRESS->
Randy Smith (Not in Mondays) 2013/05/09 01:00:57 I don't actually remember how I was thinking of th
asanka 2013/05/09 16:54:33 I added notes listing all the transitions. Let me
INTERRUPTED_INTERNAL,
+ // A request to resume this interrupted download is in progress.
+ // Only incoming transition INTERRUPTED_INTERNAL.
+ RESUMING_INTERNAL,
+
MAX_DOWNLOAD_INTERNAL_STATE,
};
@@ -297,6 +301,9 @@ class CONTENT_EXPORT DownloadItemImpl
// is completed.
void Completed();
+ // Callback invoked when the URLRequest for a download resumption has started.
+ void OnResumeRequestStarted(DownloadItem* item, net::Error error);
+
// Helper routines -----------------------------------------------------------
// Indicate that an error has occurred on the download.
« no previous file with comments | « no previous file | content/browser/download/download_item_impl.cc » ('j') | content/browser/download/download_item_impl.cc » ('J')
@@ -234,9 +234,13 @@ class CONTENT_EXPORT DownloadItemImpl
CANCELLED_INTERNAL,
// An error has interrupted the download.
- // Only incoming transition IN_PROGRESS->
+ // Only incoming transitions IN_PROGRESS-> and RESUMING_INTERNAL.
Randy Smith (Not in Mondays) 2013/05/09 01:00:57 I don't actually remember how I was thinking of th
asanka 2013/05/09 16:54:33 I added notes listing all the transitions. Let me

Powered by Google App Engine
This is Rietveld 408576698